@@ -2,14 +2,13 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: array.h,v 1.63 2004/09/28 23:58:35 mast Exp $
+|| $Id: array.h,v 1.59 2004/04/18 02:16:05 mast Exp $
 */
 
 #ifndef ARRAY_H
 #define ARRAY_H
 
 #include "svalue.h"
-#include "dmalloc.h"
 
 /* This debug tool writes out messages whenever arrays with unfinished
  * type fields are encountered. */
@@ -72,10 +71,10 @@ extern struct array *gc_internal_array;
 #define free_array(V) do{						\
     struct array *v_=(V);						\
     debug_malloc_touch(v_);						\
-    DO_IF_DEBUG (							\
-      DO_IF_PIKE_CLEANUP (						\
-	if (gc_external_refs_zapped)					\
-	  gc_check_zapped (v_, PIKE_T_ARRAY, __FILE__, __LINE__)));	\
+    DO_IF_PIKE_CLEANUP (						\
+      if (gc_external_refs_zapped)					\
+	gc_check_zapped (v_, PIKE_T_ARRAY, __FILE__, __LINE__);		\
+    );									\
     if(!sub_ref(v_))							\
       really_free_array(v_);						\
   }while(0)
@@ -125,7 +124,7 @@ INT32 set_lookup(struct array *a, struct svalue *s);
 INT32 switch_lookup(struct array *a, struct svalue *s);
 PMOD_EXPORT struct array *order_array(struct array *v, INT32 *order);
 PMOD_EXPORT struct array *reorder_and_copy_array(struct array *v, INT32 *order);
-PMOD_EXPORT TYPE_FIELD array_fix_type_field(struct array *v);
+PMOD_EXPORT void array_fix_type_field(struct array *v);
 #ifdef PIKE_DEBUG
 void array_check_type_field(struct array *v);
 #endif
