@@ -2,11 +2,11 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: interpret.c,v 1.353 2004/09/30 15:28:08 mast Exp $
+|| $Id: interpret.c,v 1.351 2004/06/01 19:12:05 mast Exp $
 */
 
 #include "global.h"
-RCSID("$Id: interpret.c,v 1.353 2004/09/30 15:28:08 mast Exp $");
+RCSID("$Id: interpret.c,v 1.351 2004/06/01 19:12:05 mast Exp $");
 #include "interpret.h"
 #include "object.h"
 #include "program.h"
@@ -167,8 +167,7 @@ void gc_mark_stack_external (struct pike_frame *f,
 
 static void gc_check_stack_callback(struct callback *foo, void *bar, void *gazonk)
 {
-  if (Pike_interpreter.evaluator_stack)
-    gc_mark_stack_external (Pike_fp, Pike_sp, Pike_interpreter.evaluator_stack);
+  gc_mark_stack_external (Pike_fp, Pike_sp, Pike_interpreter.evaluator_stack);
 }
 #endif
 
@@ -564,14 +563,7 @@ PMOD_EXPORT void find_external_context(struct external_variable_context *loc,
     Pike_fatal("No object\n");
 #endif
 
-  if (!(p = loc->o->prog)) {
-    /* magic fallback */
-    p = get_program_for_object_being_destructed(loc->o);
-    if(!p)
-    {
-      Pike_error("Cannot access parent of destructed object.\n");
-    }
-  }
+  p = loc->o->prog;
 
 #ifdef DEBUG_MALLOC
   if (loc->o->refs == 0x55555555) {
@@ -606,7 +598,7 @@ PMOD_EXPORT void find_external_context(struct external_variable_context *loc,
 
     TRACE((4,"-   o->parent_identifier=%d inherit->identifier_level=%d\n",
 	   (p->flags & PROGRAM_USES_PARENT) ?
-	   LOW_PARENT_INFO(loc->o, p)->parent_identifier : -1,
+	   PARENT_INFO(loc->o)->parent_identifier : -1,
 	   inh->identifier_level));
 
     switch(inh->parent_offset)
