@@ -1,9 +1,9 @@
-#line 1 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 /*
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: interpret_functions.h,v 1.170 2005/05/18 12:36:53 mast Exp $
+|| $Id: interpret_functions.h,v 1.168 2004/05/21 16:32:07 grubba Exp $
 */
 
 /*
@@ -294,7 +294,7 @@ OPCODE1_TAIL(F_MARK_AND_STRING, "mark & string", I_UPDATE_SP|I_UPDATE_M_SP, {
     print_return_value();
   };
 })
-#line 288 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 288 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_STRING, "string", I_UPDATE_SP, {
     copy_shared_string(Pike_sp->u.string,Pike_fp->context.prog->strings[arg1]);
     Pike_sp->type=PIKE_T_STRING;
@@ -302,7 +302,7 @@ OPCODE1(F_STRING, "string", I_UPDATE_SP, {
     Pike_sp++;
     print_return_value();
   })
-#line 295 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 295 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
 
@@ -328,7 +328,7 @@ OPCODE1(F_LOOKUP_LFUN, "->lfun", 0, {
     } else {
       /* Not found. */
       tmp.type = T_INT;
-      tmp.subtype = NUMBER_UNDEFINED;
+      tmp.subtype = 1;
       tmp.u.integer = 0;
     }
   } else {
@@ -382,7 +382,7 @@ OPCODE1_TAIL(F_MARK_AND_GLOBAL, "mark & global", I_UPDATE_SP|I_UPDATE_M_SP, {
     print_return_value();
   };
 })
-#line 366 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 366 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_GLOBAL, "global", I_UPDATE_SP, {
     low_object_index_no_free(Pike_sp,
 			     Pike_fp->current_object,
@@ -390,7 +390,7 @@ OPCODE1(F_GLOBAL, "global", I_UPDATE_SP, {
     Pike_sp++;
     print_return_value();
   })
-#line 373 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 373 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
 OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", I_UPDATE_SP|I_UPDATE_M_SP, {
@@ -424,7 +424,7 @@ OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", I_UPDATE_SP|I_UPDATE_M_SP,
     print_return_value();
   };
 })
-#line 378 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 378 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_EXTERNAL,"external", I_UPDATE_SP, {
     struct external_variable_context loc;
 
@@ -452,7 +452,7 @@ OPCODE2(F_EXTERNAL,"external", I_UPDATE_SP, {
     }
     print_return_value();
   })
-#line 405 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 405 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
 
@@ -561,10 +561,10 @@ OPCODE1(F_ARRAY_LVALUE, "[ lvalues ]", I_UPDATE_SP, {
 OPCODE1(F_CLEAR_2_LOCAL, "clear 2 local", 0, {
   free_mixed_svalues(Pike_fp->locals + arg1, 2);
   Pike_fp->locals[arg1].type = PIKE_T_INT;
-  Pike_fp->locals[arg1].subtype = NUMBER_NUMBER;
+  Pike_fp->locals[arg1].subtype = 0;
   Pike_fp->locals[arg1].u.integer = 0;
   Pike_fp->locals[arg1+1].type = PIKE_T_INT;
-  Pike_fp->locals[arg1+1].subtype = NUMBER_NUMBER;
+  Pike_fp->locals[arg1+1].subtype = 0;
   Pike_fp->locals[arg1+1].u.integer = 0;
 })
 
@@ -574,7 +574,7 @@ OPCODE1(F_CLEAR_4_LOCAL, "clear 4 local", 0, {
   for(e = 0; e < 4; e++)
   {
     Pike_fp->locals[arg1+e].type = PIKE_T_INT;
-    Pike_fp->locals[arg1+e].subtype = NUMBER_NUMBER;
+    Pike_fp->locals[arg1+e].subtype = 0;
     Pike_fp->locals[arg1+e].u.integer = 0;
   }
 })
@@ -582,7 +582,7 @@ OPCODE1(F_CLEAR_4_LOCAL, "clear 4 local", 0, {
 OPCODE1(F_CLEAR_LOCAL, "clear local", 0, {
   free_svalue(Pike_fp->locals + arg1);
   Pike_fp->locals[arg1].type = PIKE_T_INT;
-  Pike_fp->locals[arg1].subtype = NUMBER_NUMBER;
+  Pike_fp->locals[arg1].subtype = 0;
   Pike_fp->locals[arg1].u.integer = 0;
 })
 
@@ -594,7 +594,6 @@ OPCODE1(F_INC_LOCAL, "++local", I_UPDATE_SP, {
       )
   {
     push_int(++(Pike_fp->locals[arg1].u.integer));
-    Pike_fp->locals[arg1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   } else {
     push_svalue(Pike_fp->locals+arg1);
     push_int(1);
@@ -613,7 +612,6 @@ OPCODE1(F_POST_INC_LOCAL, "local++", I_UPDATE_SP, {
       )
   {
     Pike_fp->locals[arg1].u.integer++;
-    Pike_fp->locals[arg1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   } else {
     push_svalue(Pike_fp->locals + arg1);
     push_int(1);
@@ -630,7 +628,6 @@ OPCODE1(F_INC_LOCAL_AND_POP, "++local and pop", 0, {
       )
   {
     Pike_fp->locals[arg1].u.integer++;
-    Pike_fp->locals[arg1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   } else {
     push_svalue( Pike_fp->locals + arg1);
     push_int(1);
@@ -647,7 +644,6 @@ OPCODE1(F_DEC_LOCAL, "--local", I_UPDATE_SP, {
       )
   {
     push_int(--(Pike_fp->locals[arg1].u.integer));
-    Pike_fp->locals[arg1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   } else {
     push_svalue(Pike_fp->locals+arg1);
     push_int(1);
@@ -666,13 +662,13 @@ OPCODE1(F_POST_DEC_LOCAL, "local--", I_UPDATE_SP, {
       )
   {
     Pike_fp->locals[arg1].u.integer--;
-    Pike_fp->locals[arg1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   } else {
     push_svalue(Pike_fp->locals + arg1);
     push_int(1);
     o_subtract();
     stack_pop_to(Pike_fp->locals + arg1);
   }
+  /* Pike_fp->locals[instr].u.integer--; */
 })
 
 OPCODE1(F_DEC_LOCAL_AND_POP, "--local and pop", 0, {
@@ -683,7 +679,6 @@ OPCODE1(F_DEC_LOCAL_AND_POP, "--local and pop", 0, {
       )
   {
     Pike_fp->locals[arg1].u.integer--;
-    Pike_fp->locals[arg1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   } else {
     push_svalue(Pike_fp->locals + arg1);
     push_int(1);
@@ -709,18 +704,18 @@ OPCODE0(F_LTOSVAL2, "ltosval2", I_UPDATE_SP, {
   Pike_sp++;
   lvalue_to_svalue_no_free(Pike_sp-2, Pike_sp-4);
 
-  /* This is so that foo+=bar (and similar things) will be faster.
-   * It's done by freeing the old reference to foo after it has been
-   * pushed on the stack. That way foo can have only 1 reference if we
-   * are lucky, and then the low array/multiset/mapping manipulation
-   * routines can be destructive if they like.
+  /* this is so that foo+=bar (and similar things) will be faster, this
+   * is done by freeing the old reference to foo after it has been pushed
+   * on the stack. That way foo can have only 1 reference if we are lucky,
+   * and then the low array/multiset/mapping manipulation routines can be
+   * destructive if they like
    */
   if( (1 << Pike_sp[-2].type) &
       (BIT_ARRAY | BIT_MULTISET | BIT_MAPPING | BIT_STRING) )
   {
     struct svalue s;
     s.type = PIKE_T_INT;
-    s.subtype = NUMBER_NUMBER;
+    s.subtype = 0;
     s.u.integer = 0;
     assign_lvalue(Pike_sp-4, &s);
   }
@@ -733,18 +728,18 @@ OPCODE0(F_LTOSVAL3, "ltosval3", I_UPDATE_SP, {
   Pike_sp++;
   lvalue_to_svalue_no_free(Pike_sp-3, Pike_sp-5);
 
-  /* This is so that foo=foo[x..y] (and similar things) will be faster.
-   * It's done by freeing the old reference to foo after it has been
-   * pushed on the stack. That way foo can have only 1 reference if we
-   * are lucky, and then the low array/multiset/mapping manipulation
-   * routines can be destructive if they like.
+  /* this is so that foo=foo[x..y] (and similar things) will be faster, this
+   * is done by freeing the old reference to foo after it has been pushed
+   * on the stack. That way foo can have only 1 reference if we are lucky,
+   * and then the low array/multiset/mapping manipulation routines can be
+   * destructive if they like
    */
   if( (1 << Pike_sp[-3].type) &
       (BIT_ARRAY | BIT_MULTISET | BIT_MAPPING | BIT_STRING) )
   {
     struct svalue s;
     s.type = PIKE_T_INT;
-    s.subtype = NUMBER_NUMBER;
+    s.subtype = 0;
     s.u.integer = 0;
     assign_lvalue(Pike_sp-5, &s);
   }
@@ -765,7 +760,6 @@ OPCODE0(F_ADD_TO, "+=", I_UPDATE_SP, {
     {
       /* Optimization for a rather common case. Makes it 30% faster. */
       INT_TYPE val = (Pike_sp[-1].u.integer += Pike_sp[-2].u.integer);
-      Pike_sp[-1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
       assign_lvalue(Pike_sp-4,Pike_sp-1);
       Pike_sp-=2;
       pop_2_elems();
@@ -773,11 +767,11 @@ OPCODE0(F_ADD_TO, "+=", I_UPDATE_SP, {
       goto add_to_done;
     }
   }
-  /* This is so that foo+=bar (and similar things) will be faster.
-   * It's done by freeing the old reference to foo after it has been
-   * pushed on the stack. That way foo can have only 1 reference if we
-   * are lucky, and then the low array/multiset/mapping manipulation
-   * routines can be destructive if they like.
+  /* this is so that foo+=bar (and similar things) will be faster, this
+   * is done by freeing the old reference to foo after it has been pushed
+   * on the stack. That way foo can have only 1 reference if we are lucky,
+   * and then the low array/multiset/mapping manipulation routines can be
+   * destructive if they like
    */
   if( (1 << Pike_sp[-2].type) &
       (BIT_ARRAY | BIT_MULTISET | BIT_MAPPING | BIT_STRING) )
@@ -824,25 +818,24 @@ OPCODE0(F_ADD_TO_AND_POP, "+= and pop", I_UPDATE_SP, {
     {
       /* Optimization for a rather common case. Makes it 30% faster. */
       Pike_sp[-1].u.integer += Pike_sp[-2].u.integer;
-      Pike_sp[-1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
       assign_lvalue(Pike_sp-4,Pike_sp-1);
       Pike_sp-=2;
       pop_2_elems();
       goto add_to_and_pop_done;
     }
   }
-  /* This is so that foo+=bar (and similar things) will be faster.
-   * It's done by freeing the old reference to foo after it has been
-   * pushed on the stack. That way foo can have only 1 reference if we
-   * are lucky, and then the low array/multiset/mapping manipulation
-   * routines can be destructive if they like.
+  /* this is so that foo+=bar (and similar things) will be faster, this
+   * is done by freeing the old reference to foo after it has been pushed
+   * on the stack. That way foo can have only 1 reference if we are lucky,
+   * and then the low array/multiset/mapping manipulation routines can be
+   * destructive if they like
    */
   if( (1 << Pike_sp[-2].type) &
       (BIT_ARRAY | BIT_MULTISET | BIT_MAPPING | BIT_STRING) )
   {
     struct svalue s;
     s.type=PIKE_T_INT;
-    s.subtype=NUMBER_NUMBER;
+    s.subtype=0;
     s.u.integer=0;
     assign_lvalue(Pike_sp-4,&s);
   } else if (Pike_sp[-2].type == PIKE_T_OBJECT) {
@@ -1073,18 +1066,18 @@ OPCODE0_TAIL(F_MARK2, "mark mark", I_UPDATE_M_SP, {
     };
   };
 })
-#line 1018 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1011 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_TAIL(F_SYNCH_MARK, "synch mark", I_UPDATE_M_SP, {
 
     {
       *(Pike_mark_sp++)=Pike_sp;
     };
   })
-#line 1020 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1013 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_MARK, "mark", I_UPDATE_M_SP, {
       *(Pike_mark_sp++)=Pike_sp;
     })
-#line 1024 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1017 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
 OPCODE1(F_MARK_X, "mark Pike_sp-X", I_UPDATE_M_SP, {
@@ -1120,7 +1113,7 @@ OPCODE0_TAIL(F_CLEANUP_SYNCH_MARK, "cleanup synch mark", I_UPDATE_SP|I_UPDATE_M_
     }
   };
 })
-#line 1042 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1035 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP, {
     if (d_flag) {
       if (Pike_mark_sp <= Pike_interpreter.mark_stack) {
@@ -1137,7 +1130,7 @@ OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP, {
       }
     }
   })
-#line 1058 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1051 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
 OPCODE0(F_CLEAR_STRING_SUBTYPE, "clear string subtype", 0, {
@@ -1172,7 +1165,7 @@ OPCODE2_BRANCH(F_BRANCH_IF_NOT_LOCAL_ARROW, "branch if !local->x", 0, {
     pop_stack();
   };
 })
-#line 1081 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1074 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP, {
     if(!UNSAFE_IS_ZERO(Pike_sp-1))
     {
@@ -1183,7 +1176,7 @@ OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP, {
     }
     pop_stack();
   })
-#line 1091 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1084 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
       
@@ -1482,21 +1475,16 @@ OPCODE0_BRANCH(F_LOOP, "loop", I_UPDATE_SP, { /* loopcnt */
   }
 })
 
-OPCODE0_BRANCH(F_FOREACH, "foreach", 0, { /* array, lvalue, i */
+OPCODE0_BRANCH(F_FOREACH, "foreach", 0, { /* array, lvalue, X, i */
   if(Pike_sp[-4].type != PIKE_T_ARRAY)
     PIKE_ERROR("foreach", "Bad argument 1.\n", Pike_sp-3, 1);
   if(Pike_sp[-1].u.integer < Pike_sp[-4].u.array->size)
   {
     if(Pike_sp[-1].u.integer < 0)
-      /* Isn't this an internal compiler error? /mast */
       Pike_error("Foreach loop variable is negative!\n");
     assign_lvalue(Pike_sp-3, Pike_sp[-4].u.array->item + Pike_sp[-1].u.integer);
     DO_BRANCH();
     Pike_sp[-1].u.integer++;
-    DO_IF_DEBUG (
-      if (Pike_sp[-1].subtype)
-	Pike_fatal ("Got unexpected subtype in loop variable.\n");
-    );
   }else{
     /* write_to_stderr("foreach\n", 8); */
     DONT_BRANCH();
@@ -1588,11 +1576,8 @@ OPCODE0(F_NEGATE, "unary minus", 0, {
 	o_negate();
       }
       else
-    )
-    {
+      )
       Pike_sp[-1].u.integer =- Pike_sp[-1].u.integer;
-      Pike_sp[-1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
-    }
   }
   else if(Pike_sp[-1].type == PIKE_T_FLOAT)
   {
@@ -1609,7 +1594,6 @@ OPCODE0(F_NOT, "!", 0, {
   {
   case PIKE_T_INT:
     Pike_sp[-1].u.integer =! Pike_sp[-1].u.integer;
-    Pike_sp[-1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
     break;
 
   case PIKE_T_FUNCTION:
@@ -1627,7 +1611,6 @@ OPCODE0(F_NOT, "!", 0, {
   default:
     free_svalue(Pike_sp-1);
     Pike_sp[-1].type=PIKE_T_INT;
-    Pike_sp[-1].subtype = NUMBER_NUMBER;
     Pike_sp[-1].u.integer=0;
   }
 })
@@ -1661,7 +1644,6 @@ OPCODE0(F_ADD_INTS, "int+int", I_UPDATE_SP, {
     )
   {
     Pike_sp[-2].u.integer+=Pike_sp[-1].u.integer;
-    Pike_sp[-2].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
     dmalloc_touch_svalue(Pike_sp-1);
     Pike_sp--;
   }else{
@@ -1696,7 +1678,6 @@ OPCODE1(F_ADD_INT, "add integer", 0, {
      )
   {
     Pike_sp[-1].u.integer+=arg1;
-    Pike_sp[-1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   }else{
     push_int(arg1);
     f_add(2);
@@ -1711,7 +1692,6 @@ OPCODE1(F_ADD_NEG_INT, "add -integer", 0, {
      )
   {
     Pike_sp[-1].u.integer-=arg1;
-    Pike_sp[-1].subtype = NUMBER_NUMBER; /* Could have UNDEFINED there before. */
   }else{
     push_int(-arg1);
     f_add(2);
@@ -2244,7 +2224,7 @@ OPCODE1_JUMP(F_CALL_OTHER_AND_RETURN,"call other & return", I_UPDATE_ALL, {
       Pike_fatal("Function popped too many arguments: %s\n",		 \
 	    s->u.efun->name->str);					 \
     if(Pike_sp>expected_stack+1)					 \
-      Pike_fatal("Function left %"PRINTPTRDIFFT"d droppings on stack: %s\n", \
+      Pike_fatal("Function left %d droppings on stack: %s\n",		 \
            Pike_sp-(expected_stack+1),					 \
 	    s->u.efun->name->str);					 \
     if(Pike_sp == expected_stack && !s->u.efun->may_return_void)	 \
@@ -2442,11 +2422,11 @@ OPCODE1_PTRJUMP(F_COND_RECUR, "recur if not overloaded", I_UPDATE_ALL, {
     DO_RECUR(0);
   };
 })
-#line 2345 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2325 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_TAILPTRJUMP(F_RECUR, "recur", I_UPDATE_ALL, {
     DO_RECUR(0);
   })
-#line 2348 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2328 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 
 
 /* Ugly code duplication */
