@@ -1,263 +1,150 @@
-#line 214 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 214 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_UNDEFINED, "push UNDEFINED", I_UPDATE_SP)
 
-
-
-
 OPCODE0(F_CONST0, "push 0", I_UPDATE_SP)
 
-
-
 OPCODE0(F_CONST1, "push 1", I_UPDATE_SP)
 
-
-
-
 OPCODE0(F_MARK_AND_CONST0, "mark & 0", I_UPDATE_SP|I_UPDATE_M_SP)
 
-
-
-
 OPCODE0(F_MARK_AND_CONST1, "mark & 1", I_UPDATE_SP|I_UPDATE_M_SP)
 
-
-
-
 OPCODE0(F_CONST_1, "push -1", I_UPDATE_SP)
 
-
-
 OPCODE0(F_BIGNUM, "push 0x7fffffff", I_UPDATE_SP)
 
-
-
 OPCODE1(F_NUMBER, "push int", I_UPDATE_SP)
-#line 258 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 258 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_NUMBER64, "push 64-bit int", I_UPDATE_SP)
 
-
-
-
 OPCODE1(F_NEG_NUMBER, "push -int", I_UPDATE_SP)
 
-
-
 OPCODE1(F_CONSTANT, "constant", I_UPDATE_SP)
-#line 276 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 276 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_REARRANGE, "rearrange", 0)
-#line 285 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 285 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_TAIL(F_MARK_AND_STRING, "mark & string", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE1(F_STRING, "string", I_UPDATE_SP)
-#line 298 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 298 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_ARROW_STRING, "->string", I_UPDATE_SP)
 
-
-
-
-
-
-
 OPCODE1(F_LOOKUP_LFUN, "->lfun", 0)
-#line 335 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 335 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_LFUN, "local function", I_UPDATE_SP)
 
-
-
-
-
 OPCODE2(F_TRAMPOLINE, "trampoline", I_UPDATE_SP)
-#line 363 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 363 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_TAIL(F_MARK_AND_GLOBAL, "mark & global", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE1(F_GLOBAL, "global", I_UPDATE_SP)
-#line 375 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 375 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE2(F_EXTERNAL, "external", I_UPDATE_SP)
-#line 408 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 408 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_EXTERNAL_LVALUE, "& external", I_UPDATE_SP)
-#line 432 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 432 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_MARK_AND_LOCAL, "mark & local", I_UPDATE_SP|I_UPDATE_M_SP)
 
-
-
-
-
 OPCODE1(F_LOCAL, "local", I_UPDATE_SP)
 
-
-
-
 OPCODE2(F_2_LOCALS, "2 locals", I_UPDATE_SP)
 
-
-
-
-
-
 OPCODE2(F_LOCAL_2_LOCAL, "local = local", 0)
 
-
-
 OPCODE2(F_LOCAL_2_GLOBAL, "global = local", 0)
 
-
-
-
-
 OPCODE2(F_GLOBAL_2_LOCAL, "local = global", 0)
 
-
-
-
-
-
-
 OPCODE1(F_LOCAL_LVALUE, "& local", I_UPDATE_SP)
 
-
-
-
-
-
 OPCODE2(F_LEXICAL_LOCAL, "lexical local", I_UPDATE_SP)
-#line 486 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 486 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_LEXICAL_LOCAL_LVALUE, "&lexical local", I_UPDATE_SP)
-#line 499 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 499 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_ARRAY_LVALUE, "[ lvalues ]", I_UPDATE_SP)
-#line 510 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 510 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_CLEAR_2_LOCAL, "clear 2 local", 0)
-#line 520 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 520 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_CLEAR_4_LOCAL, "clear 4 local", 0)
-#line 531 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 531 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_CLEAR_LOCAL, "clear local", 0)
 
-
-
-
-
-
 OPCODE1(F_INC_LOCAL, "++local", I_UPDATE_SP)
-#line 555 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 554 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_POST_INC_LOCAL, "local++", I_UPDATE_SP)
-#line 574 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 572 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_INC_LOCAL_AND_POP, "++local and pop", 0)
-#line 591 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 588 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_DEC_LOCAL, "--local", I_UPDATE_SP)
-#line 608 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 604 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_POST_DEC_LOCAL, "local--", I_UPDATE_SP)
-#line 627 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 623 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_DEC_LOCAL_AND_POP, "--local and pop", 0)
-#line 644 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 639 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL, "lvalue to svalue", I_UPDATE_SP)
 
-
-
-
-
-
-
 OPCODE0(F_LTOSVAL2, "ltosval2", I_UPDATE_SP)
-#line 678 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 673 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL3, "ltosval3", I_UPDATE_SP)
-#line 702 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 697 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_ADD_TO, "+=", I_UPDATE_SP)
-#line 761 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 755 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_ADD_TO_AND_POP, "+= and pop", I_UPDATE_SP)
-#line 818 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 811 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_GLOBAL_LVALUE, "& global", I_UPDATE_SP)
 
-
-
-
-
 OPCODE0(F_INC, "++x", I_UPDATE_SP)
-#line 844 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 837 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_DEC, "--x", I_UPDATE_SP)
-#line 864 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 857 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_DEC_AND_POP, "x-- and pop", I_UPDATE_SP)
-#line 883 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 876 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_INC_AND_POP, "x++ and pop", I_UPDATE_SP)
-#line 902 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 895 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_POST_INC, "x++", I_UPDATE_SP)
-#line 925 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 918 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_POST_DEC, "x--", I_UPDATE_SP)
-#line 948 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 941 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_ASSIGN_LOCAL, "assign local", 0)
 
-
-
 OPCODE0(F_ASSIGN, "assign", I_UPDATE_SP)
-#line 962 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 955 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_APPLY_ASSIGN_LOCAL_AND_POP, "apply, assign local and pop", I_UPDATE_SP|I_UPDATE_M_SP)
-#line 971 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 964 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_APPLY_ASSIGN_LOCAL, "apply, assign local", I_UPDATE_ALL)
 
-
-
-
-
 OPCODE0(F_ASSIGN_AND_POP, "assign and pop", I_UPDATE_SP)
 
-
-
-
 OPCODE1(F_ASSIGN_LOCAL_AND_POP, "assign local and pop", I_UPDATE_SP)
 
-
-
-
-
-
 OPCODE1(F_ASSIGN_GLOBAL, "assign global", 0)
 
-
-
-
-
 OPCODE1(F_ASSIGN_GLOBAL_AND_POP, "assign global and pop", I_UPDATE_SP)
-#line 1005 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 998 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_POP_VALUE, "pop", I_UPDATE_SP)
 
-
-
 OPCODE1(F_POP_N_ELEMS, "pop_n_elems", I_UPDATE_SP)
 
-
-
 OPCODE0_TAIL(F_MARK2, "mark mark", I_UPDATE_M_SP)OPCODE0_TAIL(F_SYNCH_MARK, "synch mark", I_UPDATE_M_SP)OPCODE0(F_MARK, "mark", I_UPDATE_M_SP)
-#line 1026 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1019 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_MARK_X, "mark Pike_sp-X", I_UPDATE_M_SP)
 
-
-
 OPCODE0(F_POP_MARK, "pop mark", I_UPDATE_M_SP)
 
-
-
 OPCODE0(F_POP_TO_MARK, "pop to mark", I_UPDATE_SP|I_UPDATE_M_SP)
 
-
-
-
-
-
 OPCODE0_TAIL(F_CLEANUP_SYNCH_MARK, "cleanup synch mark", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP)
-#line 1060 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1053 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_CLEAR_STRING_SUBTYPE, "clear string subtype", 0)
 
-
-
-
 OPCODE0_BRANCH(F_BRANCH, "branch", 0)
 
-
-
 OPCODE2_BRANCH(F_BRANCH_IF_NOT_LOCAL_ARROW, "branch if !local->x", 0)OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP)
-#line 1094 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1087 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_WHEN_NON_ZERO, "branch if not zero", I_UPDATE_SP)
-#line 1105 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1098 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_BRANCH(F_BRANCH_IF_TYPE_IS_NOT, "branch if type is !=", I_UPDATE_SP)
-#line 1130 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1123 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_BRANCH(F_BRANCH_IF_LOCAL, "branch if local", 0)
-#line 1140 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1133 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_BRANCH(F_BRANCH_IF_NOT_LOCAL, "branch if !local", 0)
-#line 1161 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1154 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_WHEN_EQ, "branch if ==", I_UPDATE_SP)
 
 OPCODE0_BRANCH(F_BRANCH_WHEN_NE, "branch if !=", I_UPDATE_SP)
@@ -271,36 +158,29 @@ OPCODE0_BRANCH(F_BRANCH_WHEN_GT, "branch if >", I_UPDATE_SP)
 OPCODE0_BRANCH(F_BRANCH_WHEN_GE, "branch if >=", I_UPDATE_SP)
 
 OPCODE0_BRANCH(F_BRANCH_AND_POP_WHEN_ZERO, "branch & pop if zero", 0)
-#line 1179 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1172 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_AND_POP_WHEN_NON_ZERO, "branch & pop if !zero", 0)
-#line 1190 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1183 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LAND, "&&", I_UPDATE_SP)
-#line 1203 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1196 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LOR, "||", I_UPDATE_SP)
-#line 1214 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1207 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_EQ_OR, "==||", I_UPDATE_SP)
-#line 1227 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1220 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_EQ_AND, "==&&", I_UPDATE_SP)
-#line 1243 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1236 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_PTRJUMP(F_CATCH, "catch", I_UPDATE_ALL)
-#line 1262 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1255 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_RETURN(F_ESCAPE_CATCH, "escape catch", 0)
 
-
-
-
 OPCODE0_RETURN(F_EXIT_CATCH, "exit catch", I_UPDATE_SP)
 
-
-
-
-
 OPCODE1_JUMP(F_SWITCH, "switch", I_UPDATE_ALL)
-#line 1288 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1281 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_JUMP(F_SWITCH_ON_INDEX, "switch on index", I_UPDATE_ALL)
-#line 1307 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1300 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2_JUMP(F_SWITCH_ON_LOCAL, "switch on local", 0)
-#line 1360 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1353 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_INC_LOOP, "++Loop", 0)
 
 OPCODE0_BRANCH(F_DEC_LOOP, "--Loop", 0)
@@ -308,56 +188,39 @@ OPCODE0_BRANCH(F_DEC_LOOP, "--Loop", 0)
 OPCODE0_BRANCH(F_INC_NEQ_LOOP, "++Loop!=", 0)
 
 OPCODE0_BRANCH(F_DEC_NEQ_LOOP, "--Loop!=", 0)
-#line 1376 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1369 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LOOP, "loop", I_UPDATE_SP)
-#line 1389 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1382 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_FOREACH, "foreach", 0)
-#line 1410 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1398 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_MAKE_ITERATOR, "get_iterator", 0)
 
-
-
-
 OPCODE0_BRANCH(F_FOREACH_START, "foreach start", 0)
-#line 1428 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1416 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_BRANCH(F_FOREACH_LOOP, "foreach loop", 0)
-#line 1442 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1430 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_RETURN(F_RETURN_LOCAL, "return local", I_UPDATE_SP|I_UPDATE_FP)
-#line 1461 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1449 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_RETURN(F_RETURN_IF_TRUE, "return if true", I_UPDATE_SP|I_UPDATE_FP)
 
-
-
-
-
 OPCODE0_RETURN(F_RETURN_1, "return 1", I_UPDATE_SP|I_UPDATE_FP)
 
-
-
-
 OPCODE0_RETURN(F_RETURN_0, "return 0", I_UPDATE_SP|I_UPDATE_FP)
 
-
-
-
 OPCODE0_RETURN(F_RETURN, "return", I_UPDATE_FP)
 
-
-
 OPCODE0_RETURN(F_DUMB_RETURN, "dumb return", I_UPDATE_FP)
 
-
-
 OPCODE0(F_NEGATE, "unary minus", 0)
-#line 1509 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1494 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_ALIAS(F_COMPL, "~", 0, o_compl)
 
 OPCODE0(F_NOT, "!", 0)
-#line 1539 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1522 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_ALIAS(F_LSH, "<<", I_UPDATE_SP, o_lsh)
 
 OPCODE0_ALIAS(F_RSH, ">>", I_UPDATE_SP, o_rsh)
-#line 1549 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1532 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_EQ, "==", I_UPDATE_SP)
 
 OPCODE0(F_NE, "!=", I_UPDATE_SP)
@@ -372,12 +235,10 @@ OPCODE0(F_LE, "<=", I_UPDATE_SP)
 
 OPCODE0(F_ADD, "+", I_UPDATE_SP)
 
-
-
 OPCODE0(F_ADD_INTS, "int+int", I_UPDATE_SP)
-#line 1576 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1558 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_ADD_FLOATS, "float+float", I_UPDATE_SP)
-#line 1587 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1569 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_ALIAS(F_SUBTRACT, "-", I_UPDATE_SP, o_subtract)
 
 OPCODE0_ALIAS(F_AND, "&", I_UPDATE_SP, o_and)
@@ -393,60 +254,37 @@ OPCODE0_ALIAS(F_DIVIDE, "/", I_UPDATE_SP, o_divide)
 OPCODE0_ALIAS(F_MOD, "%", I_UPDATE_SP, o_mod)
 
 OPCODE1(F_ADD_INT, "add integer", 0)
-#line 1610 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1591 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_ADD_NEG_INT, "add -integer", 0)
-#line 1625 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1605 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_PUSH_ARRAY, "@", I_UPDATE_SP)
-#line 1652 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1632 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_LOCAL_LOCAL_INDEX, "local[local]", I_UPDATE_SP)
 
-
-
-
-
-
 OPCODE1(F_LOCAL_INDEX, "local index", 0)
-#line 1668 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1648 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_GLOBAL_LOCAL_INDEX, "global[local]", I_UPDATE_SP)
-#line 1682 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1662 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE2(F_LOCAL_ARROW, "local->x", I_UPDATE_SP)
-#line 1693 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1673 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_ARROW, "->x", 0)
-#line 1705 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1685 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_STRING_INDEX, "string index", 0)
-#line 1717 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1697 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_POS_INT_INDEX, "int index", 0)
 
-
-
-
-
 OPCODE1(F_NEG_INT_INDEX, "-int index", 0)
 
-
-
-
-
 OPCODE0(F_INDEX, "index", I_UPDATE_SP)
 
-
-
 OPCODE2(F_MAGIC_INDEX, "::`[]", I_UPDATE_SP)
 
-
-
 OPCODE2(F_MAGIC_SET_INDEX, "::`[]=", I_UPDATE_SP)
 
-
-
 OPCODE2(F_MAGIC_INDICES, "::_indices", I_UPDATE_SP)
 
-
-
 OPCODE2(F_MAGIC_VALUES, "::_values", I_UPDATE_SP)
 
-
-
 OPCODE0_ALIAS(F_CAST, "cast", I_UPDATE_SP, f_cast)
 
 OPCODE0_ALIAS(F_CAST_TO_INT, "cast_to_int", 0, o_cast_to_int)
@@ -454,93 +292,53 @@ OPCODE0_ALIAS(F_CAST_TO_INT, "cast_to_int", 0, o_cast_to_int)
 OPCODE0_ALIAS(F_CAST_TO_STRING, "cast_to_string", 0, o_cast_to_string)
 
 OPCODE0(F_SOFT_CAST, "soft cast", I_UPDATE_SP)
-#line 1816 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1796 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_ALIAS(F_RANGE, "range", I_UPDATE_SP, o_range)
 
 OPCODE0(F_COPY_VALUE, "copy_value", 0)
 
-
-
-
-
-
-
 OPCODE0(F_INDIRECT, "indirect", I_UPDATE_SP)
-#line 1846 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1826 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_SIZEOF, "sizeof", 0)
 
-
-
-
-
 OPCODE1(F_SIZEOF_LOCAL, "sizeof local", I_UPDATE_SP)
 
-
-
 OPCODE1_ALIAS(F_SSCANF, "sscanf", I_UPDATE_SP, o_sscanf)
-#line 1952 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1932 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_LFUN, "call lfun", I_UPDATE_ALL)OPCODE1_JUMP(F_CALL_LFUN_AND_POP, "call lfun" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_CALL_LFUN_AND_RETURN, "call lfun" " & return", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_CALL_LFUN, "mark, " "call lfun", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_CALL_LFUN_AND_POP, "mark, " "call lfun" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_MARK_CALL_LFUN_AND_RETURN, "mark, " "call lfun" " & return", I_UPDATE_ALL)
 
-
-
 OPCODE1_JUMP(F_APPLY, "apply", I_UPDATE_ALL)OPCODE1_JUMP(F_APPLY_AND_POP, "apply" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_APPLY_AND_RETURN, "apply" " & return", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_APPLY, "mark, " "apply", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_APPLY_AND_POP, "mark, " "apply" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_MARK_APPLY_AND_RETURN, "mark, " "apply" " & return", I_UPDATE_ALL)
 
-
 OPCODE0_JUMP(F_CALL_FUNCTION, "call function", I_UPDATE_ALL)OPCODE0_JUMP(F_CALL_FUNCTION_AND_POP, "call function" " & pop", I_UPDATE_ALL)OPCODE0_RETURN(F_CALL_FUNCTION_AND_RETURN, "call function" " & return", I_UPDATE_ALL)
 
 OPCODE1_JUMP(F_CALL_OTHER, "call other", I_UPDATE_ALL)
-#line 2015 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 1995 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_OTHER_AND_POP, "call other & pop", I_UPDATE_ALL)
-#line 2072 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2052 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_OTHER_AND_RETURN, "call other & return", I_UPDATE_ALL)
-#line 2178 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2158 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_CALL_BUILTIN, "call builtin", I_UPDATE_ALL)
 
-
-
 OPCODE1(F_CALL_BUILTIN_AND_POP, "call builtin & pop", I_UPDATE_ALL)
 
-
-
-
 OPCODE1_RETURN(F_CALL_BUILTIN_AND_RETURN, "call builtin & return", I_UPDATE_ALL)
 
-
-
-
-
 OPCODE1(F_MARK_CALL_BUILTIN, "mark, call builtin", I_UPDATE_ALL)
 
-
-
 OPCODE1(F_MARK_CALL_BUILTIN_AND_POP, "mark, call builtin & pop", 0)
 
-
-
-
 OPCODE1_RETURN(F_MARK_CALL_BUILTIN_AND_RETURN, "mark, call builtin & return", I_UPDATE_ALL)
 
-
-
-
-
 OPCODE1(F_CALL_BUILTIN1, "call builtin 1", I_UPDATE_ALL)
 
-
-
 OPCODE1(F_CALL_BUILTIN1_AND_POP, "call builtin1 & pop", I_UPDATE_ALL)
-#line 2294 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2274 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1_PTRJUMP(F_COND_RECUR, "recur if not overloaded", I_UPDATE_ALL)OPCODE0_TAILPTRJUMP(F_RECUR, "recur", I_UPDATE_ALL)
-#line 2351 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2331 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0_PTRJUMP(F_RECUR_AND_POP, "recur & pop", I_UPDATE_ALL)
 
-
-
-
-
-
 OPCODE0_PTRJUMP(F_TAIL_RECUR, "tail recursion", I_UPDATE_ALL)
-#line 2403 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2383 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE1(F_THIS_OBJECT, "this_object", I_UPDATE_SP)
-#line 2419 "/tmp/pikedeb.c9489edcc2/7.6/src/interpret_functions.h"
+#line 2399 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/interpret_functions.h"
 OPCODE0(F_ZERO_TYPE, "zero_type", 0)
