@@ -1,4 +1,4 @@
-#line 1 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 1 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 /*
  * $Id: kerberos.cmod,v 1.1 2004/05/13 08:57:08 grubba Exp $
  *
@@ -20,7 +20,7 @@
 #define HAVE_KRB5
 #endif
 
-#line 24 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 24 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 /* #define KRB_DEBUG */
 
 #ifdef KRB_DEBUG
@@ -38,8 +38,8 @@
 
 #undef class_Context_defined
 #define class_Context_defined
-struct program *Context_program=NULL;
-static int Context_program_fun_num=-1;
+struct program *Context_program=0;
+int Context_program_fun_num=-1;
 
 #undef var_ctx_Context_defined
 #define var_ctx_Context_defined
@@ -59,7 +59,7 @@ static ptrdiff_t Context_storage_offset;
 struct Context_struct {
 
 #ifdef var_ctx_Context_defined
-#line 40 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 40 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 krb5_context ctx;
 #endif /* var_ctx_Context_defined */
 };
@@ -70,7 +70,7 @@ krb5_context ctx;
 #undef Context_event_handler_defined
 #define Context_event_handler_defined
 static void init_Context_struct(void)
-#line 43 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 43 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 {
     krb5_error_code err_code;
     if ((err_code = krb5_init_context(&THIS->ctx))) {
@@ -85,7 +85,7 @@ static void init_Context_struct(void)
 #undef Context_event_handler_defined
 #define Context_event_handler_defined
 static void exit_Context_struct(void)
-#line 51 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 51 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 {
     if (THIS->ctx) {
       krb5_free_context(THIS->ctx);
@@ -95,21 +95,21 @@ static void exit_Context_struct(void)
   #define f_Context_authenticate_defined
 ptrdiff_t f_Context_authenticate_fun_num = 0;
 void f_Context_authenticate(INT32 args) {
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 struct pike_string * user;
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 struct pike_string * password;
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 if(args != 2) wrong_number_of_args_error("authenticate",args,2);
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 if(Pike_sp[0-2].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("authenticate",1,"string");
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 debug_malloc_pass(user=Pike_sp[0-2].u.string);
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 if(Pike_sp[1-2].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("authenticate",2,"string");
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 debug_malloc_pass(password=Pike_sp[1-2].u.string);
-#line 59 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 59 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 {
     krb5_error_code err_code;
     krb5_principal principal;
@@ -192,7 +192,7 @@ static void Context_event_handler(int ev) {
 }
 
 #endif /* Context_event_handler_defined */
-#line 124 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 124 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 #endif /* HAVE_KRB5 */
 
 PIKE_MODULE_INIT
@@ -201,10 +201,8 @@ PIKE_MODULE_INIT
 #ifdef class_Context_defined
 
 #ifdef PROG_CONTEXT_ID
-#line 38 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
   START_NEW_PROGRAM_ID(CONTEXT);
 #else
-#line 38 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
   start_new_program();
 
 #endif /* PROG_CONTEXT_ID */
@@ -228,18 +226,16 @@ PIKE_MODULE_INIT
 #endif /* Context_event_handler_defined */
 
 #ifdef f_Context_authenticate_defined
+#line 57 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
   f_Context_authenticate_fun_num =
-#line 57 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
     ADD_FUNCTION2("authenticate", f_Context_authenticate, tFunc(tString tString,"\10\0\0\0\0\0\0\0\1"), 0, OPT_EXTERNAL_DEPEND);
 
 #endif /* f_Context_authenticate_defined */
-#line 38 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
   Context_program=end_program();
-#line 38 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
   Context_program_fun_num=add_program_constant("Context",Context_program,0);
 
 #endif /* class_Context_defined */
-#line 128 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 128 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 ;
 }
 
@@ -248,13 +244,12 @@ PIKE_MODULE_EXIT
   
 #ifdef class_Context_defined
   if(Context_program) {
-#line 38 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
     free_program(Context_program);
     Context_program=0;
   }
 
 #endif /* class_Context_defined */
-#line 133 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/Kerberos/kerberos.cmod"
+#line 133 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/Kerberos/kerberos.cmod"
 ;
 }
 
