@@ -1,4 +1,4 @@
-#line 1 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 1 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 /*
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -44,8 +44,8 @@ RCSID("$Id: pcre_glue.cmod,v 1.17 2004/06/28 00:23:52 aldem Exp $");
 
 #undef class_cq__pcre_defined
 #define class_cq__pcre_defined
-struct program *cq__pcre_program=NULL;
-static int cq__pcre_program_fun_num=-1;
+struct program *cq__pcre_program=0;
+int cq__pcre_program_fun_num=-1;
 
 #undef var_re_cq__pcre_defined
 #define var_re_cq__pcre_defined
@@ -70,20 +70,20 @@ static int cq__pcre_program_fun_num=-1;
 static ptrdiff_t cq__pcre_storage_offset;
 struct cq__pcre_struct {
 
-#ifdef var_re_cq__pcre_defined
-#line 45 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
-pcre *re;
-#endif /* var_re_cq__pcre_defined */
-
-#ifdef var_extra_cq__pcre_defined
-#line 46 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
-pcre_extra *extra;
-#endif /* var_extra_cq__pcre_defined */
-
 #ifdef var_pattern_cq__pcre_defined
   struct pike_string * pattern;
 
 #endif /* var_pattern_cq__pcre_defined */
+
+#ifdef var_re_cq__pcre_defined
+#line 45 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+pcre *re;
+#endif /* var_re_cq__pcre_defined */
+
+#ifdef var_extra_cq__pcre_defined
+#line 46 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+pcre_extra *extra;
+#endif /* var_extra_cq__pcre_defined */
 };
 /*! @decl void create(string pattern, void|int options, void|object table)
  *!
@@ -115,31 +115,29 @@ pcre_extra *extra;
    #define f_cq__pcre_create_defined
 ptrdiff_t f_cq__pcre_create_fun_num = 0;
 void f_cq__pcre_create(INT32 args) {
-#line 76 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 76 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 struct pike_string * pattern;
 struct svalue * options;
-struct object * table;
-#line 76 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+struct svalue * table;
+#line 76 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args < 1) wrong_number_of_args_error("create",args,1);
-#line 76 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 76 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args > 3) wrong_number_of_args_error("create",args,3);
-#line 76 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 76 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[0-args].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("create",1,"string");
-#line 76 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 76 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 debug_malloc_pass(pattern=Pike_sp[0-args].u.string);
-if (args > 1) {if(Pike_sp[1-args].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("create",2,"void|int");
-#line 77 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
-options=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
+if (args > 1) {options=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
 } else options=0;
 if ((args > 2) && 
     ((Pike_sp[2-args].type != PIKE_T_INT) ||
      (Pike_sp[2-args].u.integer))) {
-#line 78 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 78 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[2-args].type != PIKE_T_OBJECT) SIMPLE_BAD_ARG_ERROR("create",3,"void|object");
-#line 78 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
-debug_malloc_pass(table=Pike_sp[2-args].u.object);
+#line 78 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+table=Pike_sp+2-args; dmalloc_touch_svalue(Pike_sp+2-args);
 } else table=0;
-#line 79 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 79 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 {
 	 INT32 options=0;
 	 struct object *table=NULL;
@@ -195,7 +193,7 @@ debug_malloc_pass(table=Pike_sp[2-args].u.object);
    #define f_cq__pcre_study_defined
 ptrdiff_t f_cq__pcre_study_fun_num = 0;
 void f_cq__pcre_study(INT32 args) {
-#line 130 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 130 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args != 0) wrong_number_of_args_error("study",args,0);
 {
 	 const char *errmsg=NULL;
@@ -210,7 +208,7 @@ if(args != 0) wrong_number_of_args_error("study",args,0);
 	    Pike_error("error calling pcre_study: %s\n",errmsg);
 
 	 do { struct object * ret_=(this_object());  push_object(ret_); return; }while(0);
-#line 144 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 144 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 }
 
 }
@@ -219,20 +217,20 @@ if(args != 0) wrong_number_of_args_error("study",args,0);
    #define f_cq__pcre_cq__sprintf_defined
 ptrdiff_t f_cq__pcre_cq__sprintf_fun_num = 0;
 void f_cq__pcre_cq__sprintf(INT32 args) {
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 INT_TYPE c;
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 struct mapping * flags;
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args != 2) wrong_number_of_args_error("_sprintf",args,2);
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[0-2].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("_sprintf",1,"int");
 c=Pike_sp[0-2].u.integer;
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[1-2].type != PIKE_T_MAPPING) SIMPLE_BAD_ARG_ERROR("_sprintf",2,"mapping(mixed:mixed)");
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 debug_malloc_pass(flags=Pike_sp[1-2].u.mapping);
-#line 150 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 150 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 {
       switch(c)
       {
@@ -264,7 +262,7 @@ debug_malloc_pass(flags=Pike_sp[1-2].u.mapping);
    }
 
 }
-#line 180 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 180 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 #ifdef HAVE_PCRE_FULLINFO
 
    /*! @decl mapping info()
@@ -353,7 +351,7 @@ debug_malloc_pass(flags=Pike_sp[1-2].u.mapping);
    #define f_cq__pcre_info_defined
 ptrdiff_t f_cq__pcre_info_fun_num = 0;
 void f_cq__pcre_info(INT32 args) {
-#line 265 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 265 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args != 0) wrong_number_of_args_error("info",args,0);
 {
 	 int backrefmax,firstbyte,lastliteral,capturecount;
@@ -428,7 +426,7 @@ if(args != 0) wrong_number_of_args_error("info",args,0);
       }
 
 }
-#line 338 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 338 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 #endif /* HAVE_PCRE_FULLINFO */
 
 /*! @decl int|array exec(string subject,void|int startoffset)
@@ -498,22 +496,20 @@ if(args != 0) wrong_number_of_args_error("info",args,0);
    #define f_cq__pcre_exec_defined
 ptrdiff_t f_cq__pcre_exec_fun_num = 0;
 void f_cq__pcre_exec(INT32 args) {
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 struct pike_string * subject;
 struct svalue * startoffset;
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args < 1) wrong_number_of_args_error("exec",args,1);
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args > 2) wrong_number_of_args_error("exec",args,2);
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[0-args].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("exec",1,"string");
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 debug_malloc_pass(subject=Pike_sp[0-args].u.string);
-if (args > 1) {if(Pike_sp[1-args].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("exec",2,"void|int");
-#line 405 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
-startoffset=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
+if (args > 1) {startoffset=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
 } else startoffset=0;
-#line 406 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 406 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 {
 	 struct array *res;
 
@@ -563,27 +559,27 @@ startoffset=Pike_sp+1-args; dmalloc_touch_svalue(Pike_sp+1-args);
  *!    returns the number of a named subpattern
  */
 
-#line 454 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 454 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 #ifdef HAVE_PCRE_GET_STRINGNUMBER
    #define f_cq__pcre_get_stringnumber_defined
 ptrdiff_t f_cq__pcre_get_stringnumber_fun_num = 0;
 void f_cq__pcre_get_stringnumber(INT32 args) {
-#line 455 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 455 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 struct pike_string * stringname;
-#line 455 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 455 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args != 1) wrong_number_of_args_error("get_stringnumber",args,1);
-#line 455 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 455 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[0-1].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("get_stringnumber",1,"string");
-#line 455 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 455 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 debug_malloc_pass(stringname=Pike_sp[0-1].u.string);
 {
 	 if (stringname->size_shift)
 	    SIMPLE_BAD_ARG_ERROR("get_stringnumber",1,"string (8bit)");
 	 do { INT_TYPE ret_=(pcre_get_stringnumber(THIS->re,stringname->str)); pop_stack(); push_int(ret_); return; }while(0);
-#line 460 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 460 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 }
 }
-#line 461 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 461 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 #endif /* HAVE_PCRE_GET_STRINGNUMBER */
 
 /* init and exit */
@@ -595,7 +591,7 @@ debug_malloc_pass(stringname=Pike_sp[0-1].u.string);
 #undef cq__pcre_event_handler_defined
 #define cq__pcre_event_handler_defined
 static void init_cq__pcre_struct(void)
-#line 466 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 466 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 {
 	 THIS->re=NULL;
 	 THIS->extra=NULL;
@@ -609,7 +605,7 @@ static void init_cq__pcre_struct(void)
 #undef cq__pcre_event_handler_defined
 #define cq__pcre_event_handler_defined
 static void exit_cq__pcre_struct(void)
-#line 473 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 473 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 {
 	 if (THIS->re) (*pcre_free)(THIS->re); /* -> free() usually */
 	 if (THIS->extra) (*pcre_free)(THIS->extra); /* -> free() usually */
@@ -637,7 +633,7 @@ static void cq__pcre_event_handler(int ev) {
 /*! @endclass
  */
 
-#line 483 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 483 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 #endif /* HAVE_LIBPCRE */
 
 /*! @decl array(string) split_subject(string subject, @
@@ -653,19 +649,19 @@ static void cq__pcre_event_handler(int ev) {
 #define f_split_subject_defined
 ptrdiff_t f_split_subject_fun_num = 0;
 void f_split_subject(INT32 args) {
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 struct pike_string * subject;
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 struct array * previous_result;
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(args != 2) wrong_number_of_args_error("split_subject",args,2);
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[0-2].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("split_subject",1,"string");
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 debug_malloc_pass(subject=Pike_sp[0-2].u.string);
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 if(Pike_sp[1-2].type != PIKE_T_ARRAY) SIMPLE_BAD_ARG_ERROR("split_subject",2,"array(int)");
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 debug_malloc_pass(previous_result=Pike_sp[1-2].u.array);
 {
    int i,j;
@@ -689,11 +685,11 @@ debug_malloc_pass(previous_result=Pike_sp[1-2].u.array);
    }
 
    do { struct array * ret_=(res); pop_n_elems(2); push_array(ret_); return; }while(0);
-#line 518 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 518 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 }
 
 }
-#line 520 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 520 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 /*** module init & exit & stuff *****************************************/
 
 PIKE_MODULE_EXIT
@@ -701,13 +697,12 @@ PIKE_MODULE_EXIT
    
 #ifdef class_cq__pcre_defined
   if(cq__pcre_program) {
-#line 43 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     free_program(cq__pcre_program);
     cq__pcre_program=0;
   }
 
 #endif /* class_cq__pcre_defined */
-#line 525 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 525 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 }
 
 PIKE_MODULE_INIT
@@ -988,10 +983,8 @@ PIKE_MODULE_INIT
 #ifdef class_cq__pcre_defined
 
 #ifdef PROG_CQ__PCRE_ID
-#line 43 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   START_NEW_PROGRAM_ID(CQ__PCRE);
 #else
-#line 43 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   start_new_program();
 
 #endif /* PROG_CQ__PCRE_ID */
@@ -1020,60 +1013,58 @@ PIKE_MODULE_INIT
 #endif /* cq__pcre_event_handler_defined */
 
 #ifdef f_cq__pcre_create_defined
+#line 76 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_cq__pcre_create_fun_num =
-#line 76 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("create", f_cq__pcre_create, tFunc(tString tOr(tVoid,"\10\200\0\0\0\177\377\377\377") tOr(tVoid,tObj),tVoid), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_cq__pcre_create_defined */
 
 #ifdef f_cq__pcre_study_defined
+#line 130 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_cq__pcre_study_fun_num =
-#line 130 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("study", f_cq__pcre_study, tFunc(tNone,tObj), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_cq__pcre_study_defined */
 
 #ifdef f_cq__pcre_cq__sprintf_defined
+#line 148 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_cq__pcre_cq__sprintf_fun_num =
-#line 148 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("_sprintf", f_cq__pcre_cq__sprintf, tFunc("\10\200\0\0\0\177\377\377\377" tMapping,tString), ID_STATIC, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_cq__pcre_cq__sprintf_defined */
 
 #ifdef f_cq__pcre_info_defined
+#line 265 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_cq__pcre_info_fun_num =
-#line 265 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("info", f_cq__pcre_info, tFunc(tNone,tMapping), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_cq__pcre_info_defined */
 
 #ifdef f_cq__pcre_exec_defined
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_cq__pcre_exec_fun_num =
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("exec", f_cq__pcre_exec, tFunc(tString tOr(tVoid,"\10\200\0\0\0\177\377\377\377"),tOr("\10\200\0\0\0\177\377\377\377",tArr("\10\200\0\0\0\177\377\377\377"))), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_cq__pcre_exec_defined */
 
 #ifdef f_cq__pcre_get_stringnumber_defined
+#line 455 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_cq__pcre_get_stringnumber_fun_num =
-#line 455 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("get_stringnumber", f_cq__pcre_get_stringnumber, tFunc(tString,"\10\200\0\0\0\177\377\377\377"), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_cq__pcre_get_stringnumber_defined */
-#line 43 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   cq__pcre_program=end_program();
-#line 43 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   cq__pcre_program_fun_num=add_program_constant("_pcre",cq__pcre_program,0);
 
 #endif /* class_cq__pcre_defined */
 
 #ifdef f_split_subject_defined
+#line 495 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
   f_split_subject_fun_num =
-#line 495 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
     ADD_FUNCTION2("split_subject", f_split_subject, tFunc(tString tArr("\10\200\0\0\0\177\377\377\377"),tArr(tString)), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_split_subject_defined */
-#line 803 "/tmp/pikedeb.c9489edcc2/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
+#line 803 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/modules/_Regexp_PCRE/pcre_glue.cmod"
 #endif /* HAVE_LIBPCRE */
 }
 
