@@ -1,4 +1,4 @@
-#line 1 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 1 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 /* hash.cmod -*- c -*- */
 
 #include "global.h"
@@ -53,8 +53,8 @@ werror(const char *format, ...)
 
 #undef class_HashInfo_defined
 #define class_HashInfo_defined
-struct program *HashInfo_program=NULL;
-static int HashInfo_program_fun_num=-1;
+struct program *HashInfo_program=0;
+int HashInfo_program_fun_num=-1;
 
 #undef var_meta_HashInfo_defined
 #define var_meta_HashInfo_defined
@@ -74,7 +74,7 @@ static ptrdiff_t HashInfo_storage_offset;
 struct HashInfo_struct {
 
 #ifdef var_meta_HashInfo_defined
-#line 54 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 54 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 const struct nettle_hash *meta;
 #endif /* var_meta_HashInfo_defined */
 };
@@ -85,9 +85,9 @@ const struct nettle_hash *meta;
   #define f_HashInfo_name_defined
 ptrdiff_t f_HashInfo_name_fun_num = 0;
 void f_HashInfo_name(INT32 args) {
-#line 60 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 60 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 if(args != 0) wrong_number_of_args_error("name",args,0);
-#line 62 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 62 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       if (!THIS->meta)
 	Pike_error("HashInfo not properly initialized.\n");
@@ -103,9 +103,9 @@ if(args != 0) wrong_number_of_args_error("name",args,0);
   #define f_HashInfo_digest_size_defined
 ptrdiff_t f_HashInfo_digest_size_fun_num = 0;
 void f_HashInfo_digest_size(INT32 args) {
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 if(args != 0) wrong_number_of_args_error("digest_size",args,0);
-#line 75 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 75 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       if (!THIS->meta)
 	Pike_error("HashInfo not properly initialized.\n");
@@ -121,9 +121,9 @@ if(args != 0) wrong_number_of_args_error("digest_size",args,0);
   #define f_HashInfo_block_size_defined
 ptrdiff_t f_HashInfo_block_size_fun_num = 0;
 void f_HashInfo_block_size(INT32 args) {
-#line 86 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 86 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 if(args != 0) wrong_number_of_args_error("block_size",args,0);
-#line 88 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 88 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       if (!THIS->meta)
 	Pike_error("HashInfo not properly initialized.\n");
@@ -138,7 +138,7 @@ if(args != 0) wrong_number_of_args_error("block_size",args,0);
 #undef HashInfo_event_handler_defined
 #define HashInfo_event_handler_defined
 static void init_HashInfo_struct(void)
-#line 95 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 95 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       werror("HashInfo->INIT\n");
       THIS->meta = NULL;
@@ -159,7 +159,7 @@ static void HashInfo_event_handler(int ev) {
 #endif /* HashInfo_event_handler_defined */
 /*! @endclass HashInfo */
 
-#line 103 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 103 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 #define GET_META(o) \
 ( ((struct HashInfo_struct *) get_storage((o), HashInfo_program)) \
   ->meta)
@@ -173,8 +173,8 @@ static void HashInfo_event_handler(int ev) {
 
 #undef class_HashState_defined
 #define class_HashState_defined
-struct program *HashState_program=NULL;
-static int HashState_program_fun_num=-1;
+struct program *HashState_program=0;
+int HashState_program_fun_num=-1;
 
 #undef inherit_HashInfo_HashState_defined
 #define inherit_HashInfo_HashState_defined
@@ -197,11 +197,11 @@ static ptrdiff_t HashState_storage_offset;
 struct HashState_struct {
 
 #ifdef var_ctx_HashState_defined
-#line 116 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 116 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 void *ctx;
 #endif /* var_ctx_HashState_defined */
 };
-#line 118 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 118 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 /* FIXME: Create should copy state from the other object, if
    * provided. */
 
@@ -212,15 +212,15 @@ void *ctx;
   #define f_HashState_update_defined
 ptrdiff_t f_HashState_update_fun_num = 0;
 void f_HashState_update(INT32 args) {
-#line 125 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct pike_string * data;
-#line 125 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 if(args != 1) wrong_number_of_args_error("update",args,1);
-#line 125 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 if(Pike_sp[0-1].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("update",1,"string");
-#line 125 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 125 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 debug_malloc_pass(data=Pike_sp[0-1].u.string);
-#line 127 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 127 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       const void *ctx = THIS->ctx;
       const struct nettle_hash *meta =
@@ -252,17 +252,15 @@ debug_malloc_pass(data=Pike_sp[0-1].u.string);
   #define f_HashState_digest_defined
 ptrdiff_t f_HashState_digest_fun_num = 0;
 void f_HashState_digest(INT32 args) {
-#line 154 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 154 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct svalue * arg;
-#line 154 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 154 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 if(args > 1) wrong_number_of_args_error("digest",args,1);
 if (args > 0) {
-#line 154 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
-if(Pike_sp[0-args].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("digest",1,"int|void");
-#line 154 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 154 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 arg=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 } else arg=0;
-#line 155 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 155 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       const struct nettle_hash *meta;
       struct pike_string *digest;
@@ -301,7 +299,7 @@ arg=Pike_sp+0-args; dmalloc_touch_svalue(Pike_sp+0-args);
 #undef HashState_event_handler_defined
 #define HashState_event_handler_defined
 static void init_HashState_struct(void)
-#line 186 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 186 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       werror("HashState->INIT\n");
       THIS->ctx = NULL;
@@ -313,7 +311,7 @@ static void init_HashState_struct(void)
 #undef HashState_event_handler_defined
 #define HashState_event_handler_defined
 static void exit_HashState_struct(void)
-#line 191 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 191 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       werror("HashState->EXIT\n");
       if (THIS->ctx && Pike_fp->current_object->prog)
@@ -353,8 +351,8 @@ static void HashState_event_handler(int ev) {
 
 #undef class_MD5_Info_defined
 #define class_MD5_Info_defined
-struct program *MD5_Info_program=NULL;
-static int MD5_Info_program_fun_num=-1;
+struct program *MD5_Info_program=0;
+int MD5_Info_program_fun_num=-1;
 
 #undef internal_init_MD5_Info_defined
 #define internal_init_MD5_Info_defined
@@ -362,7 +360,7 @@ static int MD5_Info_program_fun_num=-1;
 #undef MD5_Info_event_handler_defined
 #define MD5_Info_event_handler_defined
 static void init_MD5_Info_struct(void)
-#line 213 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 213 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -401,8 +399,8 @@ static void MD5_Info_event_handler(int ev) {
 
 #undef class_MD5_State_defined
 #define class_MD5_State_defined
-struct program *MD5_State_program=NULL;
-static int MD5_State_program_fun_num=-1;
+struct program *MD5_State_program=0;
+int MD5_State_program_fun_num=-1;
 
 #undef inherit_MD5_Info_MD5_State_defined
 #define inherit_MD5_Info_MD5_State_defined
@@ -428,7 +426,7 @@ static ptrdiff_t MD5_State_storage_offset;
 struct MD5_State_struct {
 
 #ifdef var_md5_MD5_State_defined
-#line 240 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 240 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct md5_ctx md5;
 #endif /* var_md5_MD5_State_defined */
 };
@@ -439,7 +437,7 @@ struct md5_ctx md5;
 #undef MD5_State_event_handler_defined
 #define MD5_State_event_handler_defined
 static void init_MD5_State_struct(void)
-#line 243 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 243 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -467,7 +465,7 @@ static void MD5_State_event_handler(int ev) {
 #endif /* MD5_State_event_handler_defined */
 /*! @endclass MD5_State */
 
-#line 257 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 257 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 #ifdef HAVE_NETTLE_MD4_INIT
 
 /*! @class MD4_Info
@@ -478,8 +476,8 @@ static void MD5_State_event_handler(int ev) {
 
 #undef class_MD4_Info_defined
 #define class_MD4_Info_defined
-struct program *MD4_Info_program=NULL;
-static int MD4_Info_program_fun_num=-1;
+struct program *MD4_Info_program=0;
+int MD4_Info_program_fun_num=-1;
 
 #undef internal_init_MD4_Info_defined
 #define internal_init_MD4_Info_defined
@@ -487,7 +485,7 @@ static int MD4_Info_program_fun_num=-1;
 #undef MD4_Info_event_handler_defined
 #define MD4_Info_event_handler_defined
 static void init_MD4_Info_struct(void)
-#line 267 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 267 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -526,8 +524,8 @@ static void MD4_Info_event_handler(int ev) {
 
 #undef class_MD4_State_defined
 #define class_MD4_State_defined
-struct program *MD4_State_program=NULL;
-static int MD4_State_program_fun_num=-1;
+struct program *MD4_State_program=0;
+int MD4_State_program_fun_num=-1;
 
 #undef inherit_MD4_Info_MD4_State_defined
 #define inherit_MD4_Info_MD4_State_defined
@@ -553,7 +551,7 @@ static ptrdiff_t MD4_State_storage_offset;
 struct MD4_State_struct {
 
 #ifdef var_md4_MD4_State_defined
-#line 294 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 294 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct md4_ctx md4;
 #endif /* var_md4_MD4_State_defined */
 };
@@ -564,7 +562,7 @@ struct md4_ctx md4;
 #undef MD4_State_event_handler_defined
 #define MD4_State_event_handler_defined
 static void init_MD4_State_struct(void)
-#line 297 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 297 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -600,8 +598,8 @@ static void MD4_State_event_handler(int ev) {
 
 #undef class_MD2_Info_defined
 #define class_MD2_Info_defined
-struct program *MD2_Info_program=NULL;
-static int MD2_Info_program_fun_num=-1;
+struct program *MD2_Info_program=0;
+int MD2_Info_program_fun_num=-1;
 
 #undef internal_init_MD2_Info_defined
 #define internal_init_MD2_Info_defined
@@ -609,7 +607,7 @@ static int MD2_Info_program_fun_num=-1;
 #undef MD2_Info_event_handler_defined
 #define MD2_Info_event_handler_defined
 static void init_MD2_Info_struct(void)
-#line 319 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 319 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -648,8 +646,8 @@ static void MD2_Info_event_handler(int ev) {
 
 #undef class_MD2_State_defined
 #define class_MD2_State_defined
-struct program *MD2_State_program=NULL;
-static int MD2_State_program_fun_num=-1;
+struct program *MD2_State_program=0;
+int MD2_State_program_fun_num=-1;
 
 #undef inherit_MD2_Info_MD2_State_defined
 #define inherit_MD2_Info_MD2_State_defined
@@ -675,7 +673,7 @@ static ptrdiff_t MD2_State_storage_offset;
 struct MD2_State_struct {
 
 #ifdef var_md2_MD2_State_defined
-#line 346 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 346 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct md2_ctx md2;
 #endif /* var_md2_MD2_State_defined */
 };
@@ -686,7 +684,7 @@ struct md2_ctx md2;
 #undef MD2_State_event_handler_defined
 #define MD2_State_event_handler_defined
 static void init_MD2_State_struct(void)
-#line 349 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 349 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -714,7 +712,7 @@ static void MD2_State_event_handler(int ev) {
 #endif /* MD2_State_event_handler_defined */
 /*! @endclass MD2_State */
 
-#line 363 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 363 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 #endif /* HAVE_NETTLE_MD4_INIT */
 
 /*! @class SHA1_Info
@@ -725,8 +723,8 @@ static void MD2_State_event_handler(int ev) {
 
 #undef class_SHA1_Info_defined
 #define class_SHA1_Info_defined
-struct program *SHA1_Info_program=NULL;
-static int SHA1_Info_program_fun_num=-1;
+struct program *SHA1_Info_program=0;
+int SHA1_Info_program_fun_num=-1;
 
 #undef internal_init_SHA1_Info_defined
 #define internal_init_SHA1_Info_defined
@@ -734,7 +732,7 @@ static int SHA1_Info_program_fun_num=-1;
 #undef SHA1_Info_event_handler_defined
 #define SHA1_Info_event_handler_defined
 static void init_SHA1_Info_struct(void)
-#line 373 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 373 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -774,8 +772,8 @@ static void SHA1_Info_event_handler(int ev) {
 
 #undef class_SHA1_State_defined
 #define class_SHA1_State_defined
-struct program *SHA1_State_program=NULL;
-static int SHA1_State_program_fun_num=-1;
+struct program *SHA1_State_program=0;
+int SHA1_State_program_fun_num=-1;
 
 #undef inherit_SHA1_Info_SHA1_State_defined
 #define inherit_SHA1_Info_SHA1_State_defined
@@ -801,7 +799,7 @@ static ptrdiff_t SHA1_State_storage_offset;
 struct SHA1_State_struct {
 
 #ifdef var_sha1_SHA1_State_defined
-#line 401 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 401 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct sha1_ctx sha1;
 #endif /* var_sha1_SHA1_State_defined */
 };
@@ -812,7 +810,7 @@ struct sha1_ctx sha1;
 #undef SHA1_State_event_handler_defined
 #define SHA1_State_event_handler_defined
 static void init_SHA1_State_struct(void)
-#line 404 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 404 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -848,8 +846,8 @@ static void SHA1_State_event_handler(int ev) {
 
 #undef class_SHA256_Info_defined
 #define class_SHA256_Info_defined
-struct program *SHA256_Info_program=NULL;
-static int SHA256_Info_program_fun_num=-1;
+struct program *SHA256_Info_program=0;
+int SHA256_Info_program_fun_num=-1;
 
 #undef internal_init_SHA256_Info_defined
 #define internal_init_SHA256_Info_defined
@@ -857,7 +855,7 @@ static int SHA256_Info_program_fun_num=-1;
 #undef SHA256_Info_event_handler_defined
 #define SHA256_Info_event_handler_defined
 static void init_SHA256_Info_struct(void)
-#line 426 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 426 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashInfo_struct *HashInfo
 	= (struct HashInfo_struct *) get_storage(Pike_fp->current_object,
@@ -897,8 +895,8 @@ static void SHA256_Info_event_handler(int ev) {
 
 #undef class_SHA256_State_defined
 #define class_SHA256_State_defined
-struct program *SHA256_State_program=NULL;
-static int SHA256_State_program_fun_num=-1;
+struct program *SHA256_State_program=0;
+int SHA256_State_program_fun_num=-1;
 
 #undef inherit_SHA256_Info_SHA256_State_defined
 #define inherit_SHA256_Info_SHA256_State_defined
@@ -924,7 +922,7 @@ static ptrdiff_t SHA256_State_storage_offset;
 struct SHA256_State_struct {
 
 #ifdef var_sha256_SHA256_State_defined
-#line 454 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 454 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 struct sha256_ctx sha256;
 #endif /* var_sha256_SHA256_State_defined */
 };
@@ -935,7 +933,7 @@ struct sha256_ctx sha256;
 #undef SHA256_State_event_handler_defined
 #define SHA256_State_event_handler_defined
 static void init_SHA256_State_struct(void)
-#line 457 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 457 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 {
       struct HashState_struct *instance
 	= (struct HashState_struct *) get_storage(Pike_fp->current_object,
@@ -965,7 +963,7 @@ static void SHA256_State_event_handler(int ev) {
 
 /*! @endmodule Nettle */
 
-#line 473 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 473 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 void
 hash_init(void)
 {
@@ -974,10 +972,8 @@ hash_init(void)
 #ifdef class_HashInfo_defined
 
 #ifdef PROG_HASHINFO_ID
-#line 52 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(HASHINFO);
 #else
-#line 52 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_HASHINFO_ID */
@@ -1001,28 +997,26 @@ hash_init(void)
 #endif /* HashInfo_event_handler_defined */
 
 #ifdef f_HashInfo_name_defined
+#line 60 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashInfo_name_fun_num =
-#line 60 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("name", f_HashInfo_name, tFunc(tNone,tString), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_HashInfo_name_defined */
 
 #ifdef f_HashInfo_digest_size_defined
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashInfo_digest_size_fun_num =
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("digest_size", f_HashInfo_digest_size, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_HashInfo_digest_size_defined */
 
 #ifdef f_HashInfo_block_size_defined
+#line 86 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashInfo_block_size_fun_num =
-#line 86 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("block_size", f_HashInfo_block_size, tFunc(tNone,"\10\200\0\0\0\177\377\377\377"), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_HashInfo_block_size_defined */
-#line 52 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   HashInfo_program=end_program();
-#line 52 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   HashInfo_program_fun_num=add_program_constant("HashInfo",HashInfo_program,0);
 
 #endif /* class_HashInfo_defined */
@@ -1030,10 +1024,8 @@ hash_init(void)
 #ifdef class_HashState_defined
 
 #ifdef PROG_HASHSTATE_ID
-#line 113 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(HASHSTATE);
 #else
-#line 113 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_HASHSTATE_ID */
@@ -1052,7 +1044,6 @@ hash_init(void)
 #endif /* THIS_HASHSTATE */
 
 #ifdef inherit_HashInfo_HashState_defined
-#line 115 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashInfo_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashInfo_HashState_defined */
 
@@ -1062,20 +1053,19 @@ hash_init(void)
 #endif /* HashState_event_handler_defined */
 
 #ifdef f_HashState_update_defined
+#line 125 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashState_update_fun_num =
     ADD_FUNCTION2("update", f_HashState_update, tFunc(tString,tObj), 0, OPT_SIDE_EFFECT);
 
 #endif /* f_HashState_update_defined */
 
 #ifdef f_HashState_digest_defined
+#line 154 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
   f_HashState_digest_fun_num =
-#line 154 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     ADD_FUNCTION2("digest", f_HashState_digest, tFunc(tOr("\10\200\0\0\0\177\377\377\377",tVoid),tString), 0, OPT_EXTERNAL_DEPEND|OPT_SIDE_EFFECT);
 
 #endif /* f_HashState_digest_defined */
-#line 113 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   HashState_program=end_program();
-#line 113 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   HashState_program_fun_num=add_program_constant("HashState",HashState_program,0);
 
 #endif /* class_HashState_defined */
@@ -1083,10 +1073,8 @@ hash_init(void)
 #ifdef class_MD5_Info_defined
 
 #ifdef PROG_MD5_INFO_ID
-#line 210 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD5_INFO);
 #else
-#line 210 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD5_INFO_ID */
@@ -1108,9 +1096,7 @@ hash_init(void)
   pike_set_prog_event_callback(MD5_Info_event_handler);
 
 #endif /* MD5_Info_event_handler_defined */
-#line 210 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD5_Info_program=end_program();
-#line 210 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD5_Info_program_fun_num=add_program_constant("MD5_Info",MD5_Info_program,0);
 
 #endif /* class_MD5_Info_defined */
@@ -1118,10 +1104,8 @@ hash_init(void)
 #ifdef class_MD5_State_defined
 
 #ifdef PROG_MD5_STATE_ID
-#line 236 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD5_STATE);
 #else
-#line 236 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD5_STATE_ID */
@@ -1140,12 +1124,10 @@ hash_init(void)
 #endif /* THIS_MD5_STATE */
 
 #ifdef inherit_MD5_Info_MD5_State_defined
-#line 238 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(MD5_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_MD5_Info_MD5_State_defined */
 
 #ifdef inherit_HashState_MD5_State_defined
-#line 239 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_MD5_State_defined */
 
@@ -1153,9 +1135,7 @@ hash_init(void)
   pike_set_prog_event_callback(MD5_State_event_handler);
 
 #endif /* MD5_State_event_handler_defined */
-#line 236 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD5_State_program=end_program();
-#line 236 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD5_State_program_fun_num=add_program_constant("MD5_State",MD5_State_program,0);
 
 #endif /* class_MD5_State_defined */
@@ -1163,10 +1143,8 @@ hash_init(void)
 #ifdef class_MD4_Info_defined
 
 #ifdef PROG_MD4_INFO_ID
-#line 264 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD4_INFO);
 #else
-#line 264 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD4_INFO_ID */
@@ -1188,9 +1166,7 @@ hash_init(void)
   pike_set_prog_event_callback(MD4_Info_event_handler);
 
 #endif /* MD4_Info_event_handler_defined */
-#line 264 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD4_Info_program=end_program();
-#line 264 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD4_Info_program_fun_num=add_program_constant("MD4_Info",MD4_Info_program,0);
 
 #endif /* class_MD4_Info_defined */
@@ -1198,10 +1174,8 @@ hash_init(void)
 #ifdef class_MD4_State_defined
 
 #ifdef PROG_MD4_STATE_ID
-#line 290 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD4_STATE);
 #else
-#line 290 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD4_STATE_ID */
@@ -1220,12 +1194,10 @@ hash_init(void)
 #endif /* THIS_MD4_STATE */
 
 #ifdef inherit_MD4_Info_MD4_State_defined
-#line 292 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(MD4_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_MD4_Info_MD4_State_defined */
 
 #ifdef inherit_HashState_MD4_State_defined
-#line 293 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_MD4_State_defined */
 
@@ -1233,9 +1205,7 @@ hash_init(void)
   pike_set_prog_event_callback(MD4_State_event_handler);
 
 #endif /* MD4_State_event_handler_defined */
-#line 290 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD4_State_program=end_program();
-#line 290 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD4_State_program_fun_num=add_program_constant("MD4_State",MD4_State_program,0);
 
 #endif /* class_MD4_State_defined */
@@ -1243,10 +1213,8 @@ hash_init(void)
 #ifdef class_MD2_Info_defined
 
 #ifdef PROG_MD2_INFO_ID
-#line 316 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD2_INFO);
 #else
-#line 316 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD2_INFO_ID */
@@ -1268,9 +1236,7 @@ hash_init(void)
   pike_set_prog_event_callback(MD2_Info_event_handler);
 
 #endif /* MD2_Info_event_handler_defined */
-#line 316 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD2_Info_program=end_program();
-#line 316 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD2_Info_program_fun_num=add_program_constant("MD2_Info",MD2_Info_program,0);
 
 #endif /* class_MD2_Info_defined */
@@ -1278,10 +1244,8 @@ hash_init(void)
 #ifdef class_MD2_State_defined
 
 #ifdef PROG_MD2_STATE_ID
-#line 342 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(MD2_STATE);
 #else
-#line 342 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_MD2_STATE_ID */
@@ -1300,12 +1264,10 @@ hash_init(void)
 #endif /* THIS_MD2_STATE */
 
 #ifdef inherit_MD2_Info_MD2_State_defined
-#line 344 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(MD2_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_MD2_Info_MD2_State_defined */
 
 #ifdef inherit_HashState_MD2_State_defined
-#line 345 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_MD2_State_defined */
 
@@ -1313,9 +1275,7 @@ hash_init(void)
   pike_set_prog_event_callback(MD2_State_event_handler);
 
 #endif /* MD2_State_event_handler_defined */
-#line 342 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD2_State_program=end_program();
-#line 342 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   MD2_State_program_fun_num=add_program_constant("MD2_State",MD2_State_program,0);
 
 #endif /* class_MD2_State_defined */
@@ -1323,10 +1283,8 @@ hash_init(void)
 #ifdef class_SHA1_Info_defined
 
 #ifdef PROG_SHA1_INFO_ID
-#line 370 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA1_INFO);
 #else
-#line 370 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA1_INFO_ID */
@@ -1348,9 +1306,7 @@ hash_init(void)
   pike_set_prog_event_callback(SHA1_Info_event_handler);
 
 #endif /* SHA1_Info_event_handler_defined */
-#line 370 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA1_Info_program=end_program();
-#line 370 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA1_Info_program_fun_num=add_program_constant("SHA1_Info",SHA1_Info_program,0);
 
 #endif /* class_SHA1_Info_defined */
@@ -1358,10 +1314,8 @@ hash_init(void)
 #ifdef class_SHA1_State_defined
 
 #ifdef PROG_SHA1_STATE_ID
-#line 397 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA1_STATE);
 #else
-#line 397 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA1_STATE_ID */
@@ -1380,12 +1334,10 @@ hash_init(void)
 #endif /* THIS_SHA1_STATE */
 
 #ifdef inherit_SHA1_Info_SHA1_State_defined
-#line 399 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(SHA1_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_SHA1_Info_SHA1_State_defined */
 
 #ifdef inherit_HashState_SHA1_State_defined
-#line 400 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_SHA1_State_defined */
 
@@ -1393,9 +1345,7 @@ hash_init(void)
   pike_set_prog_event_callback(SHA1_State_event_handler);
 
 #endif /* SHA1_State_event_handler_defined */
-#line 397 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA1_State_program=end_program();
-#line 397 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA1_State_program_fun_num=add_program_constant("SHA1_State",SHA1_State_program,0);
 
 #endif /* class_SHA1_State_defined */
@@ -1403,10 +1353,8 @@ hash_init(void)
 #ifdef class_SHA256_Info_defined
 
 #ifdef PROG_SHA256_INFO_ID
-#line 423 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA256_INFO);
 #else
-#line 423 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA256_INFO_ID */
@@ -1428,9 +1376,7 @@ hash_init(void)
   pike_set_prog_event_callback(SHA256_Info_event_handler);
 
 #endif /* SHA256_Info_event_handler_defined */
-#line 423 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA256_Info_program=end_program();
-#line 423 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA256_Info_program_fun_num=add_program_constant("SHA256_Info",SHA256_Info_program,0);
 
 #endif /* class_SHA256_Info_defined */
@@ -1438,10 +1384,8 @@ hash_init(void)
 #ifdef class_SHA256_State_defined
 
 #ifdef PROG_SHA256_STATE_ID
-#line 450 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   START_NEW_PROGRAM_ID(SHA256_STATE);
 #else
-#line 450 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   start_new_program();
 
 #endif /* PROG_SHA256_STATE_ID */
@@ -1460,12 +1404,10 @@ hash_init(void)
 #endif /* THIS_SHA256_STATE */
 
 #ifdef inherit_SHA256_Info_SHA256_State_defined
-#line 452 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(SHA256_Info_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_SHA256_Info_SHA256_State_defined */
 
 #ifdef inherit_HashState_SHA256_State_defined
-#line 453 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   low_inherit(HashState_program, NULL, -1, 0, 0, NULL);
 #endif /* inherit_HashState_SHA256_State_defined */
 
@@ -1473,13 +1415,11 @@ hash_init(void)
   pike_set_prog_event_callback(SHA256_State_event_handler);
 
 #endif /* SHA256_State_event_handler_defined */
-#line 450 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA256_State_program=end_program();
-#line 450 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
   SHA256_State_program_fun_num=add_program_constant("SHA256_State",SHA256_State_program,0);
 
 #endif /* class_SHA256_State_defined */
-#line 477 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 477 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 ;
 }
 
@@ -1490,7 +1430,6 @@ hash_exit(void)
   
 #ifdef class_HashInfo_defined
   if(HashInfo_program) {
-#line 52 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(HashInfo_program);
     HashInfo_program=0;
   }
@@ -1499,7 +1438,6 @@ hash_exit(void)
 
 #ifdef class_HashState_defined
   if(HashState_program) {
-#line 113 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(HashState_program);
     HashState_program=0;
   }
@@ -1508,7 +1446,6 @@ hash_exit(void)
 
 #ifdef class_MD5_Info_defined
   if(MD5_Info_program) {
-#line 210 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(MD5_Info_program);
     MD5_Info_program=0;
   }
@@ -1517,7 +1454,6 @@ hash_exit(void)
 
 #ifdef class_MD5_State_defined
   if(MD5_State_program) {
-#line 236 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(MD5_State_program);
     MD5_State_program=0;
   }
@@ -1526,7 +1462,6 @@ hash_exit(void)
 
 #ifdef class_MD4_Info_defined
   if(MD4_Info_program) {
-#line 264 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(MD4_Info_program);
     MD4_Info_program=0;
   }
@@ -1535,7 +1470,6 @@ hash_exit(void)
 
 #ifdef class_MD4_State_defined
   if(MD4_State_program) {
-#line 290 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(MD4_State_program);
     MD4_State_program=0;
   }
@@ -1544,7 +1478,6 @@ hash_exit(void)
 
 #ifdef class_MD2_Info_defined
   if(MD2_Info_program) {
-#line 316 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(MD2_Info_program);
     MD2_Info_program=0;
   }
@@ -1553,7 +1486,6 @@ hash_exit(void)
 
 #ifdef class_MD2_State_defined
   if(MD2_State_program) {
-#line 342 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(MD2_State_program);
     MD2_State_program=0;
   }
@@ -1562,7 +1494,6 @@ hash_exit(void)
 
 #ifdef class_SHA1_Info_defined
   if(SHA1_Info_program) {
-#line 370 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(SHA1_Info_program);
     SHA1_Info_program=0;
   }
@@ -1571,7 +1502,6 @@ hash_exit(void)
 
 #ifdef class_SHA1_State_defined
   if(SHA1_State_program) {
-#line 397 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(SHA1_State_program);
     SHA1_State_program=0;
   }
@@ -1580,7 +1510,6 @@ hash_exit(void)
 
 #ifdef class_SHA256_Info_defined
   if(SHA256_Info_program) {
-#line 423 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(SHA256_Info_program);
     SHA256_Info_program=0;
   }
@@ -1589,13 +1518,12 @@ hash_exit(void)
 
 #ifdef class_SHA256_State_defined
   if(SHA256_State_program) {
-#line 450 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
     free_program(SHA256_State_program);
     SHA256_State_program=0;
   }
 
 #endif /* class_SHA256_State_defined */
-#line 484 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Nettle/hash.cmod"
+#line 484 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Nettle/hash.cmod"
 ;
 }
 
