@@ -1,4 +1,4 @@
-#line 1 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 1 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 /* -*- c -*-
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
@@ -74,15 +74,15 @@ static void push_words0( struct pike_string *ds, struct words *w )
 #define f_split_words_defined
 ptrdiff_t f_split_words_fun_num = 0;
 void f_split_words(INT32 args) {
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 struct pike_string * input;
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(args != 1) wrong_number_of_args_error("split_words",args,1);
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(Pike_sp[0-1].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("split_words",1,"string");
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 debug_malloc_pass(input=Pike_sp[0-1].u.string);
-#line 75 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 75 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 {
   struct words *res;
   struct buffer * data;
@@ -99,15 +99,15 @@ debug_malloc_pass(input=Pike_sp[0-1].u.string);
 #define f_split_words_and_normalize_defined
 ptrdiff_t f_split_words_and_normalize_fun_num = 0;
 void f_split_words_and_normalize(INT32 args) {
-#line 87 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 87 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 struct pike_string * input;
-#line 87 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 87 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(args != 1) wrong_number_of_args_error("split_words_and_normalize",args,1);
-#line 87 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 87 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(Pike_sp[0-1].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("split_words_and_normalize",1,"string");
-#line 87 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 87 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 debug_malloc_pass(input=Pike_sp[0-1].u.string);
-#line 89 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 89 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 {
   struct words *res;
   if( !input->size_shift && (res = unicode_split_words_pikestr0( input )) )
@@ -187,21 +187,21 @@ debug_malloc_pass(input=Pike_sp[0-1].u.string);
 #define f_normalize_defined
 ptrdiff_t f_normalize_fun_num = 0;
 void f_normalize(INT32 args) {
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 struct pike_string * s;
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 struct pike_string * flags;
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(args != 2) wrong_number_of_args_error("normalize",args,2);
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(Pike_sp[0-2].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("normalize",1,"string");
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 debug_malloc_pass(s=Pike_sp[0-2].u.string);
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(Pike_sp[1-2].type != PIKE_T_STRING) SIMPLE_BAD_ARG_ERROR("normalize",2,"string");
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 debug_malloc_pass(flags=Pike_sp[1-2].u.string);
-#line 166 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 166 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 {
   int _flags=0, i;
 
@@ -213,7 +213,7 @@ debug_malloc_pass(flags=Pike_sp[1-2].u.string);
     }
 
   do { struct pike_string * ret_=(unicode_normalize( s, _flags )); pop_n_elems(2); push_string(ret_); return; }while(0);
-#line 177 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 177 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 }
 
 }
@@ -233,60 +233,60 @@ debug_malloc_pass(flags=Pike_sp[1-2].u.string);
 #define f_is_wordchar_defined
 ptrdiff_t f_is_wordchar_fun_num = 0;
 void f_is_wordchar(INT32 args) {
-#line 192 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 192 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 INT_TYPE c;
-#line 192 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 192 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(args != 1) wrong_number_of_args_error("is_wordchar",args,1);
-#line 192 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 192 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 if(Pike_sp[0-1].type != PIKE_T_INT) SIMPLE_BAD_ARG_ERROR("is_wordchar",1,"int");
 c=Pike_sp[0-1].u.integer;
 {
   do { INT_TYPE ret_=(unicode_is_wordchar( c )); pop_stack(); push_int(ret_); return; }while(0);
-#line 196 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 196 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 }
 
 }
 /*! @endmodule
  */
 
-#line 201 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 201 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 PIKE_MODULE_INIT
 {
   
 #ifdef f_split_words_defined
+#line 73 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
   f_split_words_fun_num =
-#line 73 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
     ADD_FUNCTION2("split_words", f_split_words, tFunc(tString,tArr(tString)), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_split_words_defined */
 
 #ifdef f_split_words_and_normalize_defined
+#line 87 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
   f_split_words_and_normalize_fun_num =
-#line 87 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
     ADD_FUNCTION2("split_words_and_normalize", f_split_words_and_normalize, tFunc(tString,tArr(tString)), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_split_words_and_normalize_defined */
 
 #ifdef f_normalize_defined
+#line 164 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
   f_normalize_fun_num =
-#line 164 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
     ADD_FUNCTION2("normalize", f_normalize, tFunc(tString tString,tString), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_normalize_defined */
 
 #ifdef f_is_wordchar_defined
+#line 192 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
   f_is_wordchar_fun_num =
-#line 192 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
     ADD_FUNCTION2("is_wordchar", f_is_wordchar, tFunc("\10\200\0\0\0\177\377\377\377","\10\200\0\0\0\177\377\377\377"), 0, OPT_TRY_OPTIMIZE);
 
 #endif /* f_is_wordchar_defined */
-#line 204 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 204 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 unicode_normalize_init();
 }
 
 PIKE_MODULE_EXIT
 {
   
-#line 210 "/tmp/pikedeb.c9489edcc2/7.6/src/post_modules/Unicode/unicode_module.cmod"
+#line 210 "/export/spare/pike/data/pikefarm/out_work/7.6/Pike/7.6/src/post_modules/Unicode/unicode_module.cmod"
 }
 
